@@ -39,9 +39,9 @@
 #define PL_HAVE_GL_PROC_ADDR 1
 #define PL_HAVE_GLSLANG 1
 #define PL_HAVE_LCMS 1
-#undef PL_HAVE_LIBDOVI
-#undef PL_HAVE_OPENGL
-#undef PL_HAVE_SHADERC
+#define PL_HAVE_LIBDOVI 1
+#define PL_HAVE_OPENGL 1
+#define PL_HAVE_SHADERC 1
 #define PL_HAVE_VK_PROC_ADDR 1
 #define PL_HAVE_VULKAN 1
 #define PL_HAVE_XXHASH 1
